
#include "stdafx.h"
#include "ConfigFile.h"
#include "Globals.h"
#include "MyLib.h"
#include "FS Force.h"
#include "Common.h"

//-----------------------------------------------------------------------------
// Class : CConfigFile
//-----------------------------------------------------------------------------

// declare an instance
CConfigFile ConfigFile;

BOOL CConfigFile::Init() {
	SHGetFolderPath(NULL, CSIDL_COMMON_APPDATA, NULL, SHGFP_TYPE_CURRENT, szPath);
	PathAppend(szPath, "\\FS Force");
	strcpy(FileSpec, szPath);
	PathAppend(FileSpec, "\\FSForce.cfg");
	if (!FileExists(FileSpec)) {
		MessageBox(hwnd, "Unable to locate FSForce.cfg!\n\nProgram terminating.", "FS Force", MB_ICONSTOP);
		return false;
	} else {
		return true;
	}
}	// Init

// pointer returned by this function must be deallocated ie. "free(p);"
LPSTR CConfigFile::GetSectionNames(LPSTR pszRequestedID) {
	// get a list of all section names whose ID field matches the input string.
	// Returned data is a string with the desired names packed one after the other, 
	// with an extra NULL at the end
	char szID[MAX_PATH];
	LPSTR pszBuff, pszReturnBuff, pSource, pDest;
	int buffsize, res;

	buffsize = 2000;
	do {
		pszBuff = (LPSTR)malloc(buffsize);
		res = GetPrivateProfileSectionNames(pszBuff, buffsize, FileSpec);
		if (res == buffsize - 2) {
			free(pszBuff);
			buffsize *= 2;	// double the buffer size
			pszBuff = 0;
		}
	} while (!pszBuff);

	pszReturnBuff = (LPSTR)malloc(buffsize);
	pDest = pszReturnBuff;
	pSource = pszBuff;
	while (pSource[0] != 0) {
		GetPrivateProfileString(pSource, "ID", "", szID, MAX_PATH, FileSpec);
		if (_stricmp(szID, pszRequestedID) == 0) {
			strcpy(pDest, pSource);
			pDest = StrEnd(pDest) + 1;
		}
		pSource = StrEnd(pSource) + 1;
	}
	pDest[0] = 0;		// tack on an extra NULL;
	free(pszBuff);
	return pszReturnBuff;
}	//  GetSectionNames

int CConfigFile::IsValidProfile(LPSTR pszProfile) {
	char szBuff[100];

	GetPrivateProfileString(pszProfile,"ID","",szBuff,100,FileSpec);	
	return _stricmp(szBuff,"Profile");
}	// IsValidProfile


LPSTR CConfigFile::GetFirstProfile(LPSTR szBuff) {
	LPSTR szTemp;

	szTemp = GetSectionNames("Profile");
	strcpy(szBuff, szTemp);		// this just picks off the first string, not all of them
	free(szTemp);
	return szBuff;
}	// GetFirstProfile

BOOL CConfigFile::NameInUse(LPCSTR szName) {
	LPSTR pszBuff, p;
	int buffsize, res;

	buffsize = 2000;
	do {
		pszBuff = (LPSTR)malloc(buffsize);
		res = GetPrivateProfileSectionNames(pszBuff, buffsize, FileSpec);
		if (res == buffsize - 2) {
			free(pszBuff);
			buffsize *= 2;	// double the buffer size
			pszBuff = 0;
		}
	} while (!pszBuff);

	p = pszBuff;
	while (!IsNullStr(p)) {
		if (_stricmp(szName, p) == 0) {
			free(pszBuff);
			return TRUE;
		}
		p = StrEnd(p) + 1;
	}
	free(pszBuff);
	return FALSE;
}	// NameInUse




void CConfigFile::MakeCopy(LPCSTR pSrcProfile, LPCSTR pDestProfile) {
	char szBuff[5000];

	GetPrivateProfileSection(pSrcProfile, szBuff, 5000, FileSpec);
	WritePrivateProfileSection(pDestProfile, szBuff, FileSpec);

}	// MakeCopy


